import * as express from 'express';
import { IStorageEngine, IGQLAuthContext } from '@convostack/models';
import { IAuthProvider, ILoginParams, ISuccessfulAuthResponse, IRefreshParams } from '@convostack/auth';

interface IAuthJWTOptions {
    jwtSecret: string;
    allowAnonUsers?: boolean;
    requireUserVerificationHash?: boolean;
    userDataVerificationSecret?: string;
    accessTokenTTL?: number;
    refreshTokenTTL?: number;
}
declare class AuthJWT implements IAuthProvider {
    private storage;
    private options;
    constructor(storage: IStorageEngine, options: IAuthJWTOptions);
    private validateTokenFromAuthorizationValueIfProvided;
    getGQLAuthContextHTTP(req: express.Request): Promise<IGQLAuthContext>;
    getGQLAuthContextWS(connectionParams: Readonly<Record<string, unknown>>): Promise<IGQLAuthContext>;
    login(req: express.Request, { email, externalId, name, anonymousId, hash }: ILoginParams): Promise<ISuccessfulAuthResponse>;
    refresh(req: express.Request, params: IRefreshParams): Promise<ISuccessfulAuthResponse>;
    private sign;
    private validate;
    private generateAccessToken;
    private generateRefreshToken;
    private validateRefreshToken;
    private validateAccessToken;
    private generateVerificationHash;
    private isValidEmail;
}

export { AuthJWT, IAuthJWTOptions };
